@@ -1,5 +1,4 @@
 import argparse
-from engine import verify_valid_directory, download_images
 
 parser = argparse.ArgumentParser(description='CLI tool for complimenting image classification')
 parser.add_argument('-f', '--folder', default='images', help='Specify the path of a directory in which to store photos')
@@ -11,6 +10,7 @@ help='The size of the downloaded image. Right now only square images are support
 args = parser.parse_args()
 
 def main():
+    from .engine import verify_valid_directory, download_images
     if not args.number or not args.seed: 
         raise RuntimeError('Please provide both an integer for the number of images to download, as well as an integer seed to ensure replication! See --help for more information on arguments.')
     verify_valid_directory(args.folder)
